@@ -4,8 +4,8 @@ from txn_notifications.base.models import (
     AbstractCategory,
     AbstractTemplate,
     AbstractNotification,
-    AbstractUserHandlerSettings,
-    AbstractUserCategorySettings,
+    AbstractUserHandlerSetting,
+    AbstractUserCategorySetting,
 )
 
 
@@ -27,17 +27,17 @@ class Notification(AbstractNotification):
         swappable = swappable_setting("txn_notifications", "Notification")
 
 
-class UserCategorySettings(AbstractUserCategorySettings):
-    class Meta(AbstractUserCategorySettings.Meta):
+class UserCategorySetting(AbstractUserCategorySetting):
+    class Meta(AbstractUserCategorySetting.Meta):
         abstract = False
         swappable = swappable_setting(
-            "txn_notifications", "UserCategorySettings"
+            "txn_notifications", "UserCategorySetting"
         )
 
 
-class UserHandlerSettings(AbstractUserHandlerSettings):
-    class Meta(AbstractUserHandlerSettings.Meta):
+class UserHandlerSetting(AbstractUserHandlerSetting):
+    class Meta(AbstractUserHandlerSetting.Meta):
         abstract = False
         swappable = swappable_setting(
-            "txn_notifications", "UserHandlerSettings"
+            "txn_notifications", "UserHandlerSetting"
         )
