@@ -9,11 +9,11 @@ from django.contrib.auth import get_user_model
 Category = swapper.load_model("txn_notifications", "Category")
 Template = swapper.load_model("txn_notifications", "Template")
 Notification = swapper.load_model("txn_notifications", "Notification")
-UserHandlerSettings = swapper.load_model(
-    "txn_notifications", "UserHandlerSettings"
+UserHandlerSetting = swapper.load_model(
+    "txn_notifications", "UserHandlerSetting"
 )
-UserCategorySettings = swapper.load_model(
-    "txn_notifications", "UserCategorySettings"
+UserCategorySetting = swapper.load_model(
+    "txn_notifications", "UserCategorySetting"
 )
 
 
@@ -91,13 +91,13 @@ class ReadNotification(NotificationFactory):
         model = Notification
 
 
-class UserCategorySettingsFactory(DjangoModelFactory):
+class UserCategorySettingFactory(DjangoModelFactory):
     user = factory.SubFactory(UserFactory)
     category = factory.SubFactory(CategoryFactory)
     allow = True
 
     class Meta:
-        model = UserCategorySettings
+        model = UserCategorySetting
 
 
 class UserHandlerSettingFactory(DjangoModelFactory):
@@ -106,4 +106,4 @@ class UserHandlerSettingFactory(DjangoModelFactory):
     allow = True
 
     class Meta:
-        model = UserHandlerSettings
+        model = UserHandlerSetting
